@@ -20,7 +20,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Dialog.h>
+#include <Lum/Dlg/ActionDialog.h>
 
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Integer.h>
@@ -28,7 +28,7 @@
 
 #include "Result.h"
 
-class GameStartDialog : public Lum::Dialog
+class GameStartDialog : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef commitAction;
@@ -39,7 +39,9 @@ private:
 public:
   GameStartDialog(size_t points, size_t player);
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
+
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 
   bool GetSuccess() const;
